@@ -10,7 +10,7 @@ use clap::{App, Arg, ArgMatches};
 use serde_derive::{Deserialize, Serialize};
 
 use super::{CliSubCommand, Output};
-use crate::utils::arg_parser::{ArgParser, FilePathParser, HexParser};
+use crate::utils::arg_parser::{ArgParser, FilePathParser, HexFilePathParser, HexParser};
 
 pub struct MoleculeSubCommand {}
 
@@ -27,10 +27,16 @@ impl MoleculeSubCommand {
             .about("The molecule type name defined in blockchain.mol (and extra OutPointVec)");
         let arg_binary_hex = Arg::with_name("binary-hex")
             .long("binary-hex")
+            .required_unless("hex-binary-path")
             .takes_value(true)
-            .required(true)
             .validator(|input| HexParser.validate(input))
             .about("Binary data hex format");
+        let arg_hex_binary_path = Arg::with_name("hex-binary-path")
+            .long("hex-binary-path")
+            .required_unless("binary-hex")
+            .takes_value(true)
+            .validator(|input| HexFilePathParser.validate(input))
+            .about("The hex binary file path of molecule data");
 
         let arg_json_path = Arg::with_name("json-path")
             .long("json-path")
@@ -50,7 +56,8 @@ impl MoleculeSubCommand {
                 App::new("decode")
                     .about("Decode molecule type from binary")
                     .arg(arg_type.clone())
-                    .arg(arg_binary_hex.clone()),
+                    .arg(arg_binary_hex)
+                    .arg(arg_hex_binary_path),
                 App::new("encode")
                     .about("Encode molecule type from json to binary")
                     .arg(arg_type.clone())
@@ -74,7 +81,13 @@ impl CliSubCommand for MoleculeSubCommand {
         match matches.subcommand() {
             ("decode", Some(m)) => {
                 let type_name = m.value_of("type").unwrap();
-                let binary: Vec<u8> = HexParser.from_matches(m, "binary-hex")?;
+                let binary_opt: Option<Vec<u8>> =
+                    HexParser.from_matches_opt(m, "binary-hex", false)?;
+                let binary = if let Some(binary) = binary_opt {
+                    binary
+                } else {
+                    HexFilePathParser.from_matches(m, "hex-binary-path")?
+                };
                 match type_name {
                     "Uint32" => packed::Uint32::from_slice(&binary)
                         .map(|s| Unpack::<u32>::unpack(&s).to_string())
@@ -257,7 +270,7 @@ where
     T: Entity + Into<J>,
     J: serde::Serialize,
 {
-    let json: J = T::from_slice(&binary)
+    let json: J = T::from_compatible_slice(&binary)
         .map(Into::into)
         .map_err(|err| err.to_string())?;
     Ok(Output::new_output(json))
@@ -398,7 +411,7 @@ struct RawHeader {
     pub epoch: json_types::EpochNumberWithFraction,
     pub transactions_root: H256,
     pub proposals_hash: H256,
-    pub uncles_hash: H256,
+    pub extra_hash: H256,
     pub dao: json_types::Byte32,
 }
 
@@ -413,7 +426,7 @@ impl From<packed::RawHeader> for RawHeader {
             transactions_root: input.transactions_root().unpack(),
             proposals_hash: input.proposals_hash().unpack(),
             compact_target: input.compact_target().unpack(),
-            uncles_hash: input.uncles_hash().unpack(),
+            extra_hash: input.extra_hash().unpack(),
             dao: input.dao().into(),
         }
     }
@@ -430,7 +443,7 @@ impl From<RawHeader> for packed::RawHeader {
             .transactions_root(json.transactions_root.pack())
             .proposals_hash(json.proposals_hash.pack())
             .compact_target(json.compact_target.pack())
-            .uncles_hash(json.uncles_hash.pack())
+            .extra_hash(json.extra_hash.pack())
             .dao(json.dao.into())
             .build()
     }
