@@ -507,8 +507,8 @@ impl<'a> CliSubCommand for TxSubCommand<'a> {
                     .into_iter()
                     .map(|(lock_arg, signature)| {
                         serde_json::json!({
-                            "lock-arg": format!("0x{}", hex_string(&lock_arg).unwrap()),
-                            "signature": format!("0x{}", hex_string(&signature).unwrap()),
+                            "lock-arg": format!("0x{}", hex_string(&lock_arg)),
+                            "signature": format!("0x{}", hex_string(&signature)),
                         })
                     })
                     .collect::<Vec<_>>();
@@ -557,7 +557,7 @@ impl<'a> CliSubCommand for TxSubCommand<'a> {
                 }
                 let resp = self
                     .rpc_client
-                    .send_transaction(tx.data())
+                    .send_transaction(tx.data(), Some(json_types::OutputsValidator::Passthrough))
                     .map_err(|err| format!("Send transaction error: {}", err))?;
                 Ok(Output::new_output(resp))
             }
@@ -580,9 +580,9 @@ impl<'a> CliSubCommand for TxSubCommand<'a> {
                 let address_payload = cfg.to_address_payload(since_absolute_epoch_opt);
                 let lock_script = Script::from(&address_payload);
                 let resp = serde_json::json!({
-                    "mainnet": Address::new(NetworkType::Mainnet, address_payload.clone()).to_string(),
-                    "testnet": Address::new(NetworkType::Testnet, address_payload.clone()).to_string(),
-                    "lock-arg": format!("0x{}", hex_string(address_payload.args().as_ref()).unwrap()),
+                    "mainnet": Address::new(NetworkType::Mainnet, address_payload.clone(), true).to_string(),
+                    "testnet": Address::new(NetworkType::Testnet, address_payload.clone(), true).to_string(),
+                    "lock-arg": format!("0x{}", hex_string(address_payload.args().as_ref())),
                     "lock-hash": format!("{:#x}", lock_script.calc_script_hash())
                 });
                 Ok(Output::new_output(resp))
@@ -610,7 +610,7 @@ fn print_cell_info(
     } else {
         "sighash(secp)"
     };
-    let address = Address::new(network, address_payload);
+    let address = Address::new(network, address_payload, true);
     let type_script_status = if type_script_empty { "none" } else { "some" };
     eprintln!(
         "[{}] {} => {}, (data-length: {}, type-script: {}, lock-kind: {})",
@@ -646,7 +646,9 @@ fn get_keystore_signer(
                                 let tx_hash = &input.previous_output.tx_hash;
                                 client
                                     .get_transaction(tx_hash.clone())?
-                                    .map(|tx_with_status| tx_with_status.transaction.inner)
+                                    .and_then(|tx_with_status| {
+                                        tx_with_status.transaction.map(|tx| tx.inner)
+                                    })
                                     .map(packed::Transaction::from)
                                     .map(json_types::Transaction::from)
                                     .ok_or_else(|| format!("transaction not exists: {:x}", tx_hash))
@@ -790,7 +792,7 @@ impl ReprMultisigConfig {
         let sighash_addresses = cfg
             .sighash_addresses()
             .iter()
-            .map(|payload| Address::new(network, payload.clone()).to_string())
+            .map(|payload| Address::new(network, payload.clone(), false).to_string())
             .collect();
         ReprMultisigConfig {
             sighash_addresses,
