@@ -241,7 +241,7 @@ impl<'a> WalletSubCommand<'a> {
                 password,
             )
         };
-        let from_address = Address::new(network_type, from_address_payload.clone());
+        let from_address = Address::new(network_type, from_address_payload.clone(), false);
 
         if let Some(from_locked_address) = from_locked_address.as_ref() {
             let args = from_locked_address.payload().args();
@@ -482,9 +482,14 @@ impl<'a> WalletSubCommand<'a> {
             helper.add_signature(lock_arg, signature)?;
         }
         let tx = helper.build_tx(&mut get_live_cell_fn, skip_check)?;
+        let outputs_validator = if is_type_id || skip_check || skip_check_to_address {
+            Some(json_types::OutputsValidator::Passthrough)
+        } else {
+            None
+        };
         let tx_hash = self
             .rpc_client
-            .send_transaction(tx.data())
+            .send_transaction(tx.data(), outputs_validator)
             .map_err(|err| format!("Send transaction error: {}", err))?;
         assert_eq!(tx.hash(), tx_hash.pack());
         Ok(tx)
@@ -773,7 +778,7 @@ impl<'a> CliSubCommand for WalletSubCommand<'a> {
                         .map(|(lock_hash, payload_opt, capacity)| {
                             serde_json::json!({
                                 "lock_hash": format!("{:#x}", lock_hash),
-                                "address": payload_opt.map(|payload| Address::new(network_type, payload).to_string()),
+                                "address": payload_opt.map(|payload| Address::new(network_type, payload, true).to_string()),
                                 "capacity": format!("{:#}", HumanCapacity::from(capacity)),
                             })
                         })
@@ -817,7 +822,9 @@ fn get_keystore_signer(
                         let tx_hash = &input.previous_output.tx_hash;
                         client
                             .get_transaction(tx_hash.clone())?
-                            .map(|tx_with_status| tx_with_status.transaction.inner)
+                            .and_then(|tx_with_status| {
+                                tx_with_status.transaction.map(|tx| tx.inner)
+                            })
                             .map(packed::Transaction::from)
                             .map(json_types::Transaction::from)
                             .ok_or_else(|| format!("transaction not exists: {:x}", tx_hash))
